@@ -1,7 +1,9 @@
 from .category import *
 from .country import *
+from .user import *
 from .accounting_entry import *
 from .biller import *
 from .biller_field import *
 from .channel import *
 from .provider import *
+from .request import *
